==> pipewire-docs-1%3A0.3.54-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Components", "index.html#autotoc_md0", null ],
    [ "API Documentation", "index.html#autotoc_md1", null ],
    [ "More Documentation", "index.html#autotoc_md2", null ],
    [ "Resources", "index.html#autotoc_md3", null ],
    [ "Overview", "page_overview.html", [
      [ "Motivation", "page_overview.html#autotoc_md4", null ]
    ] ],
    [ "PipeWire Design", "page_pipewire.html", "page_pipewire" ],
    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
    [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
    [ "PipeWire API", "page_api.html", "page_api" ],
    [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Globals", "globals.html", [
      [ "All", "globals.html", "globals_dup" ],
      [ "Functions", "globals_func.html", "globals_func" ],
      [ "Variables", "globals_vars.html", null ],
      [ "Typedefs", "globals_type.html", null ],
      [ "Enumerations", "globals_enum.html", null ],
      [ "Enumerator", "globals_eval.html", "globals_eval" ],
      [ "Macros", "globals_defs.html", "globals_defs" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"globals_defs_p.html",
"globals_k.html",
"group__pw__context.html#gad466760a74623341ac33d267581ddf39",
"group__pw__impl__link.html#ga67ddececedcfc23e682f0b860fcde648",
"group__pw__link.html#gaafb6d5e113016baef0cf9a8cc9405c31",
"group__pw__port.html#gac556c0b1548946709e9e99daa8b52b1b",
"group__pw__session__manager.html#gaa402cd6473e92b77d7f66d42dba6720f",
"group__spa__ansi.html#ga8dcc1e4283933e216eca2305dda3ccf6",
"group__spa__device.html#gab7ccc98f93f0269396bcbcd3efd1fdb8",
"group__spa__log.html#ga2a153ee3bd5ce9737fc4f7b6e78084f1",
"group__spa__node.html#gade24550dee986c4a1279bfbaadce1636",
"group__spa__param.html#gae226fa3f944c8881bc74fd88a7c3aa0e",
"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81a7621ee5060a7fc7cfa4d4899c183b11b",
"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaaf00cc9cdd2a272c2a99b653be8dce45c",
"group__spa__pod.html#ga77978a8da43cf2f3bc74c086b046ceb0",
"group__spa__types.html#ga4fabe70032a577729bfaa7e1cb231ac6",
"page_midi.html#autotoc_md26",
"structpw__client__session__events.html#a6005c505de498fbaaaed2dd87918773f",
"structpw__impl__port.html",
"structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02",
"structspa__interface.html",
"structspa__pod__bytes.html#acf53b79878e4a426d95574190055b5e8"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> pipewire-docs-1%3A0.3.56-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Components", "index.html#autotoc_md0", null ],
    [ "API Documentation", "index.html#autotoc_md1", null ],
    [ "More Documentation", "index.html#autotoc_md2", null ],
    [ "Resources", "index.html#autotoc_md3", null ],
    [ "Overview", "page_overview.html", [
      [ "Motivation", "page_overview.html#autotoc_md4", null ]
    ] ],
    [ "PipeWire Design", "page_pipewire.html", "page_pipewire" ],
    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
    [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
    [ "PipeWire API", "page_api.html", "page_api" ],
    [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Globals", "globals.html", [
      [ "All", "globals.html", "globals_dup" ],
      [ "Functions", "globals_func.html", "globals_func" ],
      [ "Variables", "globals_vars.html", null ],
      [ "Typedefs", "globals_type.html", null ],
      [ "Enumerations", "globals_enum.html", null ],
      [ "Enumerator", "globals_eval.html", "globals_eval" ],
      [ "Macros", "globals_defs.html", "globals_defs" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"globals_defs_p.html",
"globals_k.html",
"group__pw__context.html#gace5ee0a357a22a1dd86e3398956a621e",
"group__pw__impl__link.html#ga3baed016411a9a3d0f7407c3a9144b39",
"group__pw__link.html#gaa90bcda1ac9edbb5f2c92703f1e38d84",
"group__pw__port.html#gac5541bb77b42b3e6d41d4ee9b4c06b6f",
"group__pw__session__manager.html#gaa17ffb9525d1063cdff54c7dcc5cda2d",
"group__spa__ansi.html#ga8b943fd646e64cbd0fa60484a0900d94",
"group__spa__device.html#gab68858d85274969e6f2502e95547f429",
"group__spa__log.html#ga24e95908846b410227578abfc63b0bf0",
"group__spa__node.html#gadcbf11755fca00d5a654a79ee80fdb81",
"group__spa__param.html#gadf20a282139c86a669212c8d36262ad6",
"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81a518d2c1ae61f251ca0b9adf16fac6325",
"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaaea330d28cd1cc792d707a49b60ca2ba5",
"group__spa__pod.html#ga765ef8a7efa487db110ec67c998ff2ea",
"group__spa__types.html#ga4aae17a0b82f8be6d450a8fa3a102225",
"page_midi.html#autotoc_md25",
"structpw__client__session.html",
"structpw__impl__port.html",
"structpw__stream__events.html#a0cdc45fef5f2458a0fd11a6e9ef1f6fb",
"structspa__i18n__methods.html#a7ceb5c3a7165fbfb3ee340574881d675",
"structspa__pod__builder__state.html#ad4d8cb79bdf194c752fc697eb7d63341"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
